import { TransformOptions as TransformOptions$1 } from 'esbuild';
import { FilterPattern } from '@rollup/pluginutils';
import { Plugin } from 'rollup';

interface TransformOptions extends TransformOptions$1 {
    /**
     * Path to `tsconfig.json` file relative to `process.cwd()`.
     *
     * It will not be used if `tsconfigRaw` is provided.
     *
     * @default undefined
     * @see https://esbuild.github.io/content-types/#tsconfig-json
     */
    tsconfig?: string | undefined;
}
interface Options extends TransformOptions {
    /**
     * Whether this transformation should be performed after the chunk (bundle) has been rendered.
     *
     * If `true`, then the options `include` and `exclude` will be applied to the chunk's filename from `RollupOptions.output.file`.
     *
     * @default false
     */
    output?: boolean | undefined;
    /**
     * A valid [`picomatch`](https://github.com/micromatch/picomatch#globbing-features) glob pattern, or array of patterns.
     *
     * @default RegExp(`\\.(?:${loaderExtensions.join('|')})$`)
     * @default undefined // if `output` is `true`
     * @see https://github.com/exuanbo/rollup-plugin-esbuild-transform#include
     */
    include?: FilterPattern | undefined;
    /**
     * A valid [`picomatch`](https://github.com/micromatch/picomatch#globbing-features) glob pattern, or array of patterns.
     *
     * @default /node_modules/
     * @default undefined // if `output` is `true`
     * @see https://github.com/exuanbo/rollup-plugin-esbuild-transform#exclude
     */
    exclude?: FilterPattern | undefined;
}
declare function esbuildTransform(options?: Options | Options[]): Plugin;

export { Options, TransformOptions, esbuildTransform as default };
